==> ace_5.4.2.1.0.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/orbsvcs/Notify/Seq_Worker_T.h <==
/* -*- C++ -*- */
/**
 *  @file Seq_Worker_T.h
 *
 *  Seq_Worker_T.h,v 1.6 2004/02/04 20:20:22 parsons Exp
 *
 *  @author Pradeep Gore <pradeep@oomworks.com>
 *
 *
 */

#ifndef TAO_Notify_SEQ_WORKER_T_H
#define TAO_Notify_SEQ_WORKER_T_H
#include /**/ "ace/pre.h"

#include "notify_export.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "orbsvcs/orbsvcs/ESF/ESF_Proxy_Collection.h"
#include "orbsvcs/orbsvcs/ESF/ESF_Worker.h"
#include "Container_T.h"

/**
 * @class TAO_Notify_Seq_Worker_T
 *
 * @brief Helper to construct a sequence of IDS in a collections.
 *
 */
template <class TYPE>
class TAO_Notify_Export TAO_Notify_Seq_Worker_T : public TAO_ESF_Worker<TYPE>
{
  typedef TAO_Notify_Container_T<TYPE> CONTAINER;
  typedef TAO_ESF_Proxy_Collection<TYPE> COLLECTION;
  typedef typename TYPE::SEQ SEQ;
  typedef typename TYPE::SEQ_VAR SEQ_VAR;

public:
  /// Constructor
  TAO_Notify_Seq_Worker_T (void);

  /// create a SEQ
  SEQ* create (CONTAINER& container ACE_ENV_ARG_DECL);

protected:
  ///= TAO_ESF_Worker method
  void work (TYPE* object ACE_ENV_ARG_DECL);

  /// The result
  SEQ_VAR seq_;
};

#if defined (__ACE_INLINE__)
#include "Seq_Worker_T.inl"
#endif /* __ACE_INLINE__ */

#if defined (ACE_TEMPLATES_REQUIRE_SOURCE)
#include "Seq_Worker_T.cpp"
#endif /* ACE_TEMPLATES_REQUIRE_SOURCE */

#if defined (ACE_TEMPLATES_REQUIRE_PRAGMA)
#pragma implementation ("Seq_Worker_T.cpp")
#endif /* ACE_TEMPLATES_REQUIRE_PRAGMA */

#include /**/ "ace/post.h"
#endif /* TAO_Notify_SEQ_WORKER_T_H */

==> ace_5.4.7.orig.tar.gz: ACE_wrappers/TAO/orbsvcs/orbsvcs/Notify/Seq_Worker_T.h <==
/* -*- C++ -*- */
/**
 *  @file Seq_Worker_T.h
 *
 *  Seq_Worker_T.h,v 1.8 2004/09/08 19:22:45 jtc Exp
 *
 *  @author Pradeep Gore <pradeep@oomworks.com>
 *
 *
 */

#ifndef TAO_Notify_SEQ_WORKER_T_H
#define TAO_Notify_SEQ_WORKER_T_H
#include /**/ "ace/pre.h"

#include "notify_serv_export.h"

#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
#endif /* ACE_LACKS_PRAGMA_ONCE */

#include "orbsvcs/ESF/ESF_Proxy_Collection.h"
#include "orbsvcs/ESF/ESF_Worker.h"
#include "Container_T.h"

/**
 * @class TAO_Notify_Seq_Worker_T
 *
 * @brief Helper to construct a sequence of IDS in a collections.
 *
 */
template <class TYPE>
class TAO_Notify_Serv_Export TAO_Notify_Seq_Worker_T : public TAO_ESF_Worker<TYPE>
{
  typedef TAO_Notify_Container_T<TYPE> CONTAINER;
  typedef TAO_ESF_Proxy_Collection<TYPE> COLLECTION;
  typedef typename TYPE::SEQ SEQ;
  typedef typename TYPE::SEQ_VAR SEQ_VAR;

public:
  /// Constructor
  TAO_Notify_Seq_Worker_T (void);

  /// create a SEQ
  SEQ* create (CONTAINER& container ACE_ENV_ARG_DECL);

protected:
  ///= TAO_ESF_Worker method
  void work (TYPE* object ACE_ENV_ARG_DECL);

  /// The result
  SEQ_VAR seq_;
};

#if defined (__ACE_INLINE__)
#include "Seq_Worker_T.inl"
#endif /* __ACE_INLINE__ */

#if defined (ACE_TEMPLATES_REQUIRE_SOURCE)
#include "Seq_Worker_T.cpp"
#endif /* ACE_TEMPLATES_REQUIRE_SOURCE */

#if defined (ACE_TEMPLATES_REQUIRE_PRAGMA)
#pragma implementation ("Seq_Worker_T.cpp")
#endif /* ACE_TEMPLATES_REQUIRE_PRAGMA */

#include /**/ "ace/post.h"
#endif /* TAO_Notify_SEQ_WORKER_T_H */
